==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/syncer/leechcraft_syncer_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>LeechCraft::Plugins::Syncer::Core</name>
    <message>
        <location filename="core.cpp" line="206"/>
        <location filename="core.cpp" line="222"/>
        <source>Sync failure</source>
        <translation>Ошибка синхронизации</translation>
    </message>
    <message>
        <location filename="core.cpp" line="207"/>
        <source>Login error when synchronizing plugin %1.</source>
        <translation>Ошибка входа при синхронизации плагина %1.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="223"/>
        <source>Connection error when synchronizing plugin %1.</source>
        <translation>Ошибка соединения при синхронизации плагина %1.</translation>
    </message>
    <message numerus="yes">
        <location filename="core.cpp" line="242"/>
        <source>%n item(s) received</source>
        <translation>
            <numerusform>%n элемент получен</numerusform>
            <numerusform>%n элемента получено</numerusform>
            <numerusform>%n элементов получено</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="core.cpp" line="244"/>
        <source>%n item(s) sent</source>
        <translation>
            <numerusform>%n элемент отправлен</numerusform>
            <numerusform>%n элемента отправлено</numerusform>
            <numerusform>%n элементов отправлено</numerusform>
        </translation>
    </message>
    <message>
        <location filename="core.cpp" line="245"/>
        <source>Sync</source>
        <translation>Синхронизация</translation>
    </message>
    <message>
        <location filename="core.cpp" line="240"/>
        <source>Successfully synchronized plugin %1</source>
        <oldsource>Successfully synchronized plugin %1: %2 items received, %3 items sent.</oldsource>
        <translation>Плагин %1 успешно синхронизирован</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Syncer::Plugin</name>
    <message>
        <location filename="syncer.cpp" line="59"/>
        <source>Synchronization plugin for LeechCraft</source>
        <translation>Плагин синхронизации для LeechCraft</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.65.tar.bz2: leechcraft-0.4.65/src/plugins/syncer/leechcraft_syncer_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>LeechCraft::Plugins::Syncer::Core</name>
    <message>
        <location filename="core.cpp" line="206"/>
        <location filename="core.cpp" line="222"/>
        <source>Sync failure</source>
        <translation>Ошибка синхронизации</translation>
    </message>
    <message>
        <location filename="core.cpp" line="207"/>
        <source>Login error when synchronizing plugin %1.</source>
        <translation>Ошибка входа при синхронизации плагина %1.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="223"/>
        <source>Connection error when synchronizing plugin %1.</source>
        <translation>Ошибка соединения при синхронизации плагина %1.</translation>
    </message>
    <message numerus="yes">
        <location filename="core.cpp" line="242"/>
        <source>%n item(s) received</source>
        <translation>
            <numerusform>%n элемент получен</numerusform>
            <numerusform>%n элемента получено</numerusform>
            <numerusform>%n элементов получено</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="core.cpp" line="244"/>
        <source>%n item(s) sent</source>
        <translation>
            <numerusform>%n элемент отправлен</numerusform>
            <numerusform>%n элемента отправлено</numerusform>
            <numerusform>%n элементов отправлено</numerusform>
        </translation>
    </message>
    <message>
        <location filename="core.cpp" line="245"/>
        <source>Sync</source>
        <translation>Синхронизация</translation>
    </message>
    <message>
        <location filename="core.cpp" line="240"/>
        <source>Successfully synchronized plugin %1</source>
        <oldsource>Successfully synchronized plugin %1: %2 items received, %3 items sent.</oldsource>
        <translation>Плагин %1 успешно синхронизирован</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Syncer::Plugin</name>
    <message>
        <location filename="syncer.cpp" line="69"/>
        <source>Synchronization plugin for LeechCraft</source>
        <translation>Плагин синхронизации для LeechCraft</translation>
    </message>
</context>
<context>
    <name>syncersettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <location filename="dummy.cpp" line="3"/>
        <source>Sync settings</source>
        <translation>Настройки синхронизации</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Server</source>
        <translation>Сервер</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Login:</source>
        <translation>Логин:</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="7"/>
        <source>Connection</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="8"/>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="9"/>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
</context>
</TS>
